% Halfbridge Low-High transition Voltage integral (area) function.
% Returns the area (Volts*seconds) of PWM signal from the LS FET turn-off to the HS FET turn-on.
% That is, the PWM area during the DT (DeadTime) duration
% Ilh is the OPF inductor current _at the time of the transition_, it must include ripple current

function A=Alh(Ilh,PVDD,Cout,DT);

A=zeros(length(Ilh),1);

for g=1:length(Ilh),
  if Ilh(g) > 0
    A(g)=0;
  elseif Ilh(g) > -PVDD*Cout/DT
    % Linear region
    A(g)=1/2*DT^2/Cout*-Ilh(g);
  else
    % Ilh <= -PVDD*Cout/DT
    % Hyperbolic region
    A(g)=PVDD*DT-1/2*Cout/-Ilh(g)*PVDD^2;
  end;
end;



